@@ -239,13 +239,15 @@ gok_input_ext_devices_exist (void)
 static gboolean   
 gok_input_open (GokInput *input)
 {
-  GtkWidget *window = gok_main_get_main_window ();
-  if (input) 
-      input->open = FALSE;
+  GtkWidget *window;
 
-#ifdef HAVE_XINPUT  
+  g_return_val_if_fail (input != NULL, FALSE);
+  input->open = FALSE;
+
+#ifdef HAVE_XINPUT
+  window = gok_main_get_main_window ();
   if (window && window->window && 
-      input && input->info && (input->info->use == IsXExtensionDevice))
+      input->info && (input->info->use == IsXExtensionDevice))
     {
       gdk_error_trap_push ();
       input->device = XOpenDevice(GDK_WINDOW_XDISPLAY (window->window), 
@@ -254,9 +256,9 @@ gok_input_open (GokInput *input)
 	  input->open = TRUE;
     }
 #endif
-  if (!input && !input->open)
-    g_warning ("could not open device %s", input);
-  
+  if (input->name && !input->open)
+    g_warning ("could not open device %s", input->name);
+
   return input->open;
 }
 
@@ -284,9 +286,10 @@ gok_input_get_device_list (void)
   int		num_devices;
   Display      *display;
   GtkWidget    *pMainWindow = gok_main_get_main_window ();
-  XDeviceInfo  *devices;
 
 #ifdef HAVE_XINPUT
+  XDeviceInfo  *devices;
+
   if (!input_device_list && pMainWindow && pMainWindow->window) {
 	  display = GDK_WINDOW_XDISPLAY (pMainWindow->window); 
  
@@ -328,7 +331,6 @@ find_input (Display	*display,
 	    char	*name,
 	    gboolean     extended_only)
 {
-	GokInput *input = NULL;
 	GSList *device_list = gok_input_get_device_list ();
 	
 	while (device_list && device_list->data) {
@@ -347,8 +349,6 @@ find_input_by_id (Display     *display,
 		  guint        id,
 		  gboolean     extended_only)
 {
-	int		i;
-	int		num_devices;
 	GSList *devices = gok_input_get_device_list ();
 	
 	while (devices && devices->data) {
@@ -371,7 +371,6 @@ gok_input_init (GdkFilterFunc filter_func)
 	XEventClass      event_list[40];
 	int              number;
 	GtkWidget       *window = gok_main_get_main_window ();
-	Display         *display;
 	GdkWindow       *root;
 	GSList          *device_list = gok_input_get_device_list ();
 	
